SignInButton class

Inheritance

Constructors

SignInButton(Buttons button, {Key? key, required VoidCallback? onPressed, bool mini = false, EdgeInsets padding = const EdgeInsets.all(0), ShapeBorder? shape, String? text, double elevation = 2.0, double? width})
The constructor is fairly self-explanatory.
const

Properties

button → Buttons
button should be used from the enum class Buttons
final
elevation → double
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mini → bool
mini is a boolean field which specify whether to use a square mini button.
final
onPressed → VoidCallback?
Here are the buttons builder which integrate with button builder and the buttons list.
final
padding → EdgeInsets
overrides the default button padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
shape is to specify the custom shape of the widget.
final
text → String?
overrides the default button text
final
width → double?
overrides the default button width
final

Methods

build(BuildContext context) → Widget
The build function is used to build the widget which will switch to desired widget based on the enum class Buttons
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited